==> wicket-1.3.7-sources.jar: org/apache/wicket/markup/html/form/SimpleFormComponentLabel.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.markup.html.form;

import org.apache.wicket.markup.ComponentTag;
import org.apache.wicket.markup.MarkupStream;

/**
 * A form component label that replaces its body with the contents of
 * {@link FormComponent#getLabel()}
 * 
 * @author Igor Vaynberg (ivaynberg)
 */
public class SimpleFormComponentLabel extends FormComponentLabel
{
	private static final long serialVersionUID = 1L;

	/**
	 * Construct.
	 * 
	 * @param id
	 *            component id
	 * @param labelProvider
	 *            label provider (e.g. FormComponent, Radio, Check)
	 */
	public SimpleFormComponentLabel(String id, LabeledWebMarkupContainer labelProvider)
	{
		super(id, labelProvider);
		if (labelProvider.getLabel() == null)
		{
			throw new IllegalStateException("Provided form component does not have a label set. "
					+ "Use FormComponent.setLabel(IModel) to set the model "
					+ "that will feed this label");
		}
		setModel(labelProvider.getLabel());
	}

	/**
	 * @see org.apache.wicket.Component#onComponentTagBody(org.apache.wicket.markup.MarkupStream,
	 *      org.apache.wicket.markup.ComponentTag)
	 */
	protected void onComponentTagBody(final MarkupStream markupStream, final ComponentTag openTag)
	{
		replaceComponentTagBody(markupStream, openTag, getModelObjectAsString());
	}
}

==> wicket-1.4-rc4-sources.jar: org/apache/wicket/markup/html/form/SimpleFormComponentLabel.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.wicket.markup.html.form;

import org.apache.wicket.markup.ComponentTag;
import org.apache.wicket.markup.MarkupStream;

/**
 * A form component label that replaces its body with the contents of
 * {@link FormComponent#getLabel()}
 * 
 * @author Igor Vaynberg (ivaynberg)
 */
public class SimpleFormComponentLabel extends FormComponentLabel
{
	private static final long serialVersionUID = 1L;

	/**
	 * Construct.
	 * 
	 * @param id
	 *            component id
	 * @param labelProvider
	 *            label provider (e.g. FormComponent, Radio, Check)
	 */
	public SimpleFormComponentLabel(String id, LabeledWebMarkupContainer labelProvider)
	{
		super(id, labelProvider);
		if (labelProvider.getLabel() == null)
		{
			throw new IllegalStateException("Provided form component does not have a label set. "
				+ "Use FormComponent.setLabel(IModel) to set the model "
				+ "that will feed this label");
		}
		setDefaultModel(labelProvider.getLabel());
	}

	/**
	 * @see org.apache.wicket.Component#onComponentTagBody(org.apache.wicket.markup.MarkupStream,
	 *      org.apache.wicket.markup.ComponentTag)
	 */
	@Override
	protected void onComponentTagBody(final MarkupStream markupStream, final ComponentTag openTag)
	{
		replaceComponentTagBody(markupStream, openTag, getDefaultModelObjectAsString());
	}
}
